  #include <windows.h>
  #include <stdio.h>
  #include <conio.h>


#include "Lab_Uino_inc.c"

/* instruction register bit positions, see HD44780U data sheet */
#define LCD_CLR               0      /* DB0: clear display                  */
#define LCD_HOME              1      /* DB1: return to home position        */
#define LCD_ENTRY_MODE        2      /* DB2: set entry mode                 */
#define LCD_ENTRY_INC         1      /*   DB1: 1=increment, 0=decrement     */
#define LCD_ENTRY_SHIFT       0      /*   DB2: 1=display shift on           */
#define LCD_ON                3      /* DB3: turn lcd/cursor on             */
#define LCD_ON_DISPLAY        2      /*   DB2: turn display on              */
#define LCD_ON_CURSOR         1      /*   DB1: turn cursor on               */
#define LCD_ON_BLINK          0      /*     DB0: blinking cursor ?          */
#define LCD_MOVE              4      /* DB4: move cursor/display            */
#define LCD_MOVE_DISP         3      /*   DB3: move display (0-> cursor) ?  */
#define LCD_MOVE_RIGHT        2      /*   DB2: move right (0-> left) ?      */
#define LCD_FUNCTION          5      /* DB5: function set                   */
#define LCD_FUNCTION_8BIT     4      /*   DB4: set 8BIT mode (0->4BIT mode) */
#define LCD_FUNCTION_2LINES   3      /*   DB3: two lines (0->one line)      */
#define LCD_FUNCTION_10DOTS   2      /*   DB2: 5x10 font (0->5x7 font)      */
#define LCD_CGRAM             6      /* DB6: set CG RAM address             */
#define LCD_DDRAM             7      /* DB7: set DD RAM address             */
#define LCD_BUSY              7      /* DB7: LCD is busy                    */

/* set entry mode: display shift on/off, dec/inc cursor move direction */
#define LCD_ENTRY_DEC            0x04   /* display shift off, dec cursor move dir */
#define LCD_ENTRY_DEC_SHIFT      0x05   /* display shift on,  dec cursor move dir */
#define LCD_ENTRY_INC_           0x06   /* display shift off, inc cursor move dir */
#define LCD_ENTRY_INC_SHIFT      0x07   /* display shift on,  inc cursor move dir */

/* display on/off, cursor on/off, blinking char at cursor position */
#define LCD_DISP_OFF             0x08   /* display off                            */
#define LCD_DISP_ON              0x0C   /* display on, cursor off                 */
#define LCD_DISP_ON_BLINK        0x0D   /* display on, cursor off, blink char     */
#define LCD_DISP_ON_CURSOR       0x0E   /* display on, cursor on                  */
#define LCD_DISP_ON_CURSOR_BLINK 0x0F   /* display on, cursor on, blink char      */

/* move cursor/shift display */
#define LCD_MOVE_CURSOR_LEFT     0x10   /* move cursor left  (decrement)          */
#define LCD_MOVE_CURSOR_RIGHT    0x14   /* move cursor right (increment)          */
#define LCD_MOVE_DISP_LEFT       0x18   /* shift display left                     */
#define LCD_MOVE_DISP_RIGHT      0x1C   /* shift display right                    */

/* function set: set interface data length and number of display lines */
#define LCD_FUNCTION_4BIT_1LINE  0x20   /* 4-bit interface, single line, 5x7 dots */
#define LCD_FUNCTION_4BIT_2LINES 0x28   /* 4-bit interface, dual line,   5x7 dots */
#define LCD_FUNCTION_8BIT_1LINE  0x30   /* 8-bit interface, single line, 5x7 dots */
#define LCD_FUNCTION_8BIT_2LINES 0x38   /* 8-bit interface, dual line,   5x7 dots */


#define LCD_MODE_DEFAULT     ((1<<LCD_ENTRY_MODE) | (1<<LCD_ENTRY_INC) )

void lcd_data(unsigned char data)
{
    unsigned char dataBits ;
        led_off(14);
        led_on(13); //LCD_RS_On; 
        if(data&(1<<4))led_on(9); else led_off(9);
        if(data&(1<<5))led_on(10); else led_off(10);
        if(data&(1<<6))led_on(11); else led_off(11);
        if(data&(1<<7))led_on(12); else led_off(12);
        led_on(14); //
        led_off(14);//LCD_E_On;

        if(data&(1<<0))led_on(9); else led_off(9);
        if(data&(1<<1))led_on(10); else led_off(10);
        if(data&(1<<2))led_on(11); else led_off(11);
        if(data&(1<<3))led_on(12); else led_off(12);
        led_on(14); //
        led_off(14);//LCD_E_On;
        Sleep(2);  
}

void lcd_command(unsigned char data)
{
    unsigned char dataBits ;
        led_off(14);
        led_off(13); //LCD_RS_off; 
        if(data &(1<<4))led_on(9); else led_off(9);
        if(data &(1<<5))led_on(10); else led_off(10);
        if(data &(1<<6))led_on(11); else led_off(11);
        if(data &(1<<7))led_on(12); else led_off(12);
        led_on(14); //
        led_off(14);//LCD_E_On;

        if(data&(1<<0))led_on(9); else led_off(9);
        if(data&(1<<1))led_on(10); else led_off(10);
        if(data&(1<<2))led_on(11); else led_off(11);
        if(data&(1<<3))led_on(12); else led_off(12);
        led_on(14); //
        led_off(14);//LCD_E_On;
        Sleep(2);  
}


void lcd_clrscr(void)
{
    lcd_command(1<<LCD_CLR);
    Sleep(2);  
}

/*************************************************************************
Set cursor to home position
*************************************************************************/
void lcd_home(void)
{
    lcd_command(1<<LCD_HOME);
    Sleep(2);  
}


/*************************************************************************
Display character at current cursor position
Input:    character to be displayed
Returns:  none
*************************************************************************/
void lcd_putc(char c)
{
   lcd_data(c);
   Sleep(2);  
}

/*************************************************************************
Display string without auto linefeed
Input:    string to be displayed
Returns:  none
*************************************************************************/
void lcd_puts(unsigned char *s)
/* print string on lcd (no auto linefeed) */
{
    unsigned char c;
    while ( (c = *s++) ) {
        lcd_putc(c);
        Sleep(2);  
    }

}/* lcd_puts */


/*************************************************************************
Initialize display and select type of cursor
Input:    dispAttr LCD_DISP_OFF            display off
                   LCD_DISP_ON             display on, cursor off
                   LCD_DISP_ON_CURSOR      display on, cursor on
                   LCD_DISP_CURSOR_BLINK   display on, cursor on flashing
Returns:  none
*************************************************************************/
void lcd_init(unsigned char dispAttr)
{

    Sleep(20);        /* wait 16ms or more after power-on       */

    lcd_data(3);
    Sleep(6);          /* delay, busy flag can't be checked here */
    lcd_data(3);
//    Sleep(2);          /* delay, busy flag can't be checked here */
    lcd_data(3);
//    Sleep(2);          /* delay, busy flag can't be checked here */



    lcd_data(2);
//    Sleep(2);          /* delay, busy flag can't be checked here */
    lcd_data(2);
//    Sleep(2);          /* delay, busy flag can't be checked here */
    lcd_data(80);
//    Sleep(2);          /* delay, busy flag can't be checked here */
    lcd_data(10);
    lcd_data(40);

//    lcd_command(LCD_FUNCTION_DEFAULT);      /* function set: display lines  */


    lcd_command(LCD_DISP_OFF);              /* display on                  */
    lcd_clrscr();                           /* display clear                */
    lcd_command(LCD_MODE_DEFAULT);          /* set entry mode               */
    lcd_command(dispAttr);                  /* display/cursor control       */

}/* lcd_init */




int main()
    {
 int x;
int valor;

    load_kit();

    lcd_init(LCD_DISP_ON_CURSOR);
    lcd_data('W');
    lcd_data('l');
    lcd_data('a');




    printf("lendo buffer - aperte chave error para sair");

    do{
        read_buf(Usb_buffer);
        printf("\n\rbuffer: ");
        for(x=0;x<8;x++)
             printf("%02x ",Usb_buffer[x]);

    }while(!(Usb_buffer[0]&(1<<0)));
  
    printf("\n\ragardando chave sel_out ");
    while(!read_key(7));printf("chave sel_out apertada \n");
    printf("\n\ragardando chave paper_out ");
    while(!read_key(6));printf("chave paper_out apertada \n");
    printf("\n\ragardando chave prog ");
    while(!read_key(5));printf("chave prog apertada \n");
    printf("\n\ragardando chave busy ");
    while(!read_key(4));printf("chave busy apertada \n");
    printf("\n\ragardando chave ack ");
    while(!read_key(3));printf("chave ack apertada \n");
    printf("\n\ragardando chave error ");
    while(!read_key(1));printf("chave error apertada \n");

    printf("lendo conversores ADs - aperte error para sair");
    do{
      x=read_adc(0);
      printf("\n\r ADC0: %d ",x);
      x=read_adc(1);
      printf(" ADC1: %d ",x);
      x=read_adc(4);
      printf(" ADC4: %d ",x);
      x=read_adc(5);
      printf(" ADC5: %d ",x);
      x=read_adc(7);
      printf(" temp: %d ",x);
    }while(!read_key(3));

    printf("\n\testando leds");
	write_buf("ST");Sleep(500);
	write_buf("RT");Sleep(500);
	
    printf("\n\rpiscando leds");
    
    for(x=0;x<10;x++){
       write_data_led(255);
       write_ctr_led(255);
	   Sleep(500);
       write_data_led(0);
       write_ctr_led(0);
	   Sleep(500);
    }
      for(x=0;x<13;x++){
       led_on(x);
	   Sleep(250);
    }
       for(x=0;x<13;x++){
       led_off(x);
	   Sleep(250);
    }
  
    for(x=0;x<13;x++){
       led_toggle(x);
	   Sleep(100);
    }
    for(x=0;x<13;x++){
       led_toggle(x);
	   Sleep(100);
    }
  
    for(x=0;x<100;x++){
        valor = read_keys();
        printf("\n\rchaves: ");
             printf("%02x ",valor);
    }

    
    
    printf("\n\r FIM  -  tecle enter para sair");

    stop_kit();
    getch();

    return 0;
      }
